@@ -152,6 +152,15 @@ QString LinkedInAPI::delete_company_following(QString id){
 	return api_delete("http://api.linkedin.com/v1/people/~/following/companies/id="+id);
 }
 
+/**
+  Unbookmark a job bookmark
+  @param id The  id of the job to unbookmark
+  @return The signed url from liboauth to use when requesting the company xml
+  */
+QString LinkedInAPI::delete_job_bookmark(QString id){
+	return api_delete("http://api.linkedin.com/v1/people/~/job-bookmarks/"+id);
+}
+
 /**
   Search for a person
   @param search The search string
@@ -178,6 +187,20 @@ QString LinkedInAPI::search_company(QString search,QString start, QString count)
 	return api_request("http://api.linkedin.com/v1/company-search:(companies:(id,name,universal-name,website-url,logo-url,type),num-results)?start="+start+"&count="+count+"&keywords=" + search);
 }
 
+/**
+  Search for a job
+  @param search The search string
+  @param start The number of results to start at. ie, if there are 300 search
+  results and you want to start at result number 20.
+  @param count The number of results to return in total
+  @return The url to use when posting a GET for a job search
+  */
+QString LinkedInAPI::search_job(QString search,QString start, QString count){
+	search = QUrl::toPercentEncoding(search);
+	return api_request("http://api.linkedin.com/v1/job-search:(jobs:(id,customer-job-code,active,expiration-date,posting-timestamp,expiration-timestamp,company:(id,name,logo-url),position:(title,location,job-functions,industries,job-type,experience-level),skills-and-experience,description-snippet,description,salary,job-poster:(id,first-name,last-name,headline),referral-bonus,site-job-url,location-description))?start="+start+"&count="+count+"&keywords=" + search);
+}
+
+
 /**
   Get the companies the user is currently following
   @param start The number of results to start at. ie, if there are 300
@@ -189,6 +212,17 @@ QString LinkedInAPI::get_company_following(QString start, QString count){
 	return api_request("http://api.linkedin.com/v1/people/~/following/companies:(id,name,universal-name,website-url,logo-url,type)?start="+start+"&count="+count);
 }
 
+/**
+  Get the jobs the user has bookmarked
+  @param start The number of results to start at. ie, if there are 300
+  results and you want to start at result number 20.
+  @param count The number of results to return in total
+  @return The url to use when posting a GET to get a list of companies the user follows
+  */
+QString LinkedInAPI::get_job_bookmarks(QString start, QString count){
+	return api_request("http://api.linkedin.com/v1/people/~/job-bookmarks:(job:(id,customer-job-code,active,expiration-date,posting-timestamp,expiration-timestamp,company:(id,name,logo-url),position:(title,location,job-functions,industries,job-type,experience-level),skills-and-experience,description-snippet,description,salary,job-poster:(id,first-name,last-name,headline),referral-bonus,site-job-url,location-description))?start="+start+"&count="+count);
+}
+
 QString LinkedInAPI::get_connections_current(){
 	return (api_request("http://api.linkedin.com/v1/people/~/connections"));
 }
@@ -209,6 +243,14 @@ QString LinkedInAPI::get_person_following_company(){
 	return (api_request("http://api.linkedin.com/v1/people/~/following/companies"));
 }
 
+/**
+  Get the jobs that the user has currently bookmarked
+  @return the jobs that the user has bookmarked
+  */
+QString LinkedInAPI::get_person_bookmark_job(){
+	return api_request("http://api.linkedin.com/v1/people/~/job-bookmarks");
+}
+
 QString LinkedInAPI::get_connections_by_id(QString id){
 	return (api_request("http://api.linkedin.com/v1/people/id="+id+"/connections"));
 }
@@ -235,6 +277,15 @@ QString LinkedInAPI::get_company_by_id(QString id){
 	return (api_request("http://api.linkedin.com/v1/companies/"+id+":(id,name,ticker,description,logo-url,square-logo-url,website-url,industry,size,status,specialties,locations)"));
 }
 
+/**
+  Get a job's profile
+  @param id The ID that identifies the job
+  @return the URL to use as in a GET that returns the job profile XML
+  */
+QString LinkedInAPI::get_job_by_id(QString id){
+	return api_request("http://api.linkedin.com/v1/jobs/"+id+":(id,customer-job-code,active,expiration-date,posting-timestamp,expiration-timestamp,company:(id,name,logo-url),position:(title,location,job-functions,industries,job-type,experience-level),skills-and-experience,description-snippet,description,salary,job-poster:(id,first-name,last-name,headline),referral-bonus,site-job-url,location-description)");
+}
+
 QStringList LinkedInAPI::post_status(QString status){
 
 	/*create the XML that linkedin uses to make the status*/
@@ -428,7 +479,7 @@ QStringList LinkedInAPI::post_comment(QString networkKey, QString comment){
 /**
   Start following a company
   @param id The id of the company to follow
-  @return A list containing a signed url, an authorization header, and a body to be PUT
+  @return A list containing a signed url, an authorization header, and a body to be POSTed
   */
 QStringList LinkedInAPI::post_company_follow(QString id){
 	QDomDocument xml;
@@ -448,6 +499,33 @@ QStringList LinkedInAPI::post_company_follow(QString id){
 	return api_post("http://api.linkedin.com/v1/people/~/following/companies", xml.toString());
 }
 
+/**
+  Bookmark a job
+  @param id The id of the job to bookmark
+  @return A list containing a signed url, an authorization header, and a body to be POSTed
+  */
+QStringList LinkedInAPI::post_job_bookmark(QString id){
+	QDomDocument xml;
+
+	QDomProcessingInstruction pi = xml.createProcessingInstruction("xml", "version=\"1.0\" encoding=\"UTF-16\"");
+	xml.appendChild(pi);
+
+	QDomElement root = xml.createElement("job-bookmark");
+	xml.appendChild(root);
+
+	QDomElement node = xml.createElement("job");
+	root.appendChild(node);
+
+
+	QDomElement jobNode = xml.createElement("id");
+	QDomText nodeText = xml.createTextNode(id);
+	jobNode.appendChild(nodeText);
+
+
+	node.appendChild(jobNode);
+	return api_post("http://api.linkedin.com/v1/people/~/job-bookmarks", xml.toString());
+}
+
 /**
   Like or unlike a share
   @param networkKey identifies what is to be liked / unliked
