@@ -27,6 +27,7 @@ public:
 	Q_INVOKABLE QString get_person_by_id(QString id);
 	Q_INVOKABLE QString get_person_public_by_id(QString id);
 	Q_INVOKABLE QString get_person_following_company();
+	Q_INVOKABLE QString get_person_bookmark_job();
 	Q_INVOKABLE QString get_connections_current();
 	Q_INVOKABLE QString get_connections_by_id(QString id);
 	Q_INVOKABLE QString get_updates_current();
@@ -35,12 +36,16 @@ public:
 	Q_INVOKABLE QString get_company_by_id(QString id);
 	Q_INVOKABLE QString get_company_suggestions();
 	Q_INVOKABLE QString get_company_following(QString start, QString count);
+	Q_INVOKABLE QString get_job_bookmarks(QString start, QString count);
+	Q_INVOKABLE QString get_job_by_id(QString id);
 
 	Q_INVOKABLE QString search_person(QString search, QString start, QString count);
 	Q_INVOKABLE QString search_company(QString search, QString start, QString count);
+	Q_INVOKABLE QString search_job(QString search, QString start, QString count);
 
 
 	Q_INVOKABLE QString delete_company_following(QString id);
+	Q_INVOKABLE QString delete_job_bookmark(QString id);
 
 
 	Q_INVOKABLE QStringList put_like(QString networkKey, QString boolean);
@@ -52,6 +57,7 @@ public:
 	Q_INVOKABLE QStringList post_invitation(QString email, QString firstName, QString lastName, QString subjectBody, QString message);
 	Q_INVOKABLE QStringList post_comment(QString networkKey, QString comment);
 	Q_INVOKABLE QStringList post_company_follow(QString id);
+	Q_INVOKABLE QStringList post_job_bookmark(QString id);
 
 	QString generate_header(char* params);
 
