@@ -24,12 +24,18 @@ public:
 	Q_INVOKABLE void addConnection(QString id, QString firstName);
 	Q_INVOKABLE void removeConnection(QString id);
 
+	Q_INVOKABLE void setJobsBookmarked(QString xml);
+	Q_INVOKABLE bool bookmarked(QString id);
+	Q_INVOKABLE void bookmark(QString id, QString firstName);
+	Q_INVOKABLE void removeBookmark(QString id);
+
 	void print();
 
 
 private:
 	QHash<QString,QString>* companiesFollowed;
 	QHash<QString,QString>* peopleConnections;
+	QHash<QString,QString>* jobsBookmarked;
 
 };
 
